==> create-serverless-function-0.0.1.tgz: package/createServerlessFunction.js <==
#!/usr/bin/env node
/******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId]) {
/******/ 			return installedModules[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			i: moduleId,
/******/ 			l: false,
/******/ 			exports: {}
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.l = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// define getter function for harmony exports
/******/ 	__webpack_require__.d = function(exports, name, getter) {
/******/ 		if(!__webpack_require__.o(exports, name)) {
/******/ 			Object.defineProperty(exports, name, {
/******/ 				configurable: false,
/******/ 				enumerable: true,
/******/ 				get: getter
/******/ 			});
/******/ 		}
/******/ 	};
/******/
/******/ 	// getDefaultExport function for compatibility with non-harmony modules
/******/ 	__webpack_require__.n = function(module) {
/******/ 		var getter = module && module.__esModule ?
/******/ 			function getDefault() { return module['default']; } :
/******/ 			function getModuleExports() { return module; };
/******/ 		__webpack_require__.d(getter, 'a', getter);
/******/ 		return getter;
/******/ 	};
/******/
/******/ 	// Object.prototype.hasOwnProperty.call
/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(__webpack_require__.s = 1);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ (function(module, exports) {

module.exports = require("handlebars");

/***/ }),
/* 1 */
/***/ (function(module, exports, __webpack_require__) {

const chalk = __webpack_require__(2);

const path = __webpack_require__(3);
const fs = __webpack_require__(4);

const program = __webpack_require__(5);

program.version('0.1.0')
    .arguments('<name> <directory>')
    .parse(process.argv);

if (program.args.length != 2) program.help();

function generateIndexJs(functionName, targetDir) {
    console.log(chalk.yellow('Generating index.js'));

    fs.mkdirSync(path.resolve(targetDir, 'src'));

    const indexJsTemplate = __webpack_require__(6);
    const indexJsPath = path.resolve(targetDir, 'src', 'index.js');
    const indexJsBody = indexJsTemplate({ name: functionName });

    fs.writeFileSync(indexJsPath, indexJsBody);

    console.log(chalk.green('Generated index.js'));
}

function generatePackageJson(functionName, targetDir) {
    console.log(chalk.yellow('Generating package.json'));

    const packageJson = {
        "name": functionName,
        "version": "0.0.1",
        "main": 'index.js',
        "devDependencies": {
            "babel-core": "^6.25.0",
            "babel-jest": "^20.0.3",
            "babel-loader": "^7.1.1",
            "babel-preset-env": "^1.6.0",
            "generate-package-json-webpack-plugin": "^0.1.2",
            "jest": "^20.0.4",
            "regenerator-runtime": "^0.10.5",
            "webpack": "^3.3.0",
            "webpack-node-externals": "^1.6.0"
        },
        "scripts": {
            "test": "jest",
            "build": "webpack --config ./config/webpack.config.js"
        },
        "jest": {
            "testEnvironment": "node"
        }
    };

    const packageJsonPath = path.resolve(targetDir, 'package.json');
    const packageJsonBody = JSON.stringify(packageJson, null, '    ');
    
    fs.writeFileSync(packageJsonPath, packageJsonBody);

    console.log(chalk.green('Generated package.json'));
}

function generateWebpackConfig(functionName, targetDir) {
    console.log(chalk.yellow('Generating WebPack configuration'));

    fs.mkdirSync(path.resolve(targetDir, 'config'));

    const webpackConfigTemplate = __webpack_require__(7);
    const webpackConfigPath = path.resolve(targetDir, 'config', 'webpack.config.js');
    const webpackConfigBody = webpackConfigTemplate({ name: functionName });

    fs.writeFileSync(webpackConfigPath, webpackConfigBody);

    console.log(chalk.green('Generated webpack configuration'));
}

generateIndexJs(...program.args);
generatePackageJson(...program.args);
generateWebpackConfig(...program.args);




/***/ }),
/* 2 */
/***/ (function(module, exports) {

module.exports = require("chalk");

/***/ }),
/* 3 */
/***/ (function(module, exports) {

module.exports = require("path");

/***/ }),
/* 4 */
/***/ (function(module, exports) {

module.exports = require("fs");

/***/ }),
/* 5 */
/***/ (function(module, exports) {

module.exports = require("commander");

/***/ }),
/* 6 */
/***/ (function(module, exports, __webpack_require__) {

var Handlebars = __webpack_require__(0);
module.exports = (Handlebars['default'] || Handlebars).template({"compiler":[7,">= 4.0.0"],"main":function(container,depth0,helpers,partials,data) {
    var helper, alias1=depth0 != null ? depth0 : (container.nullContext || {}), alias2=helpers.helperMissing, alias3="function", alias4=container.escapeExpression;

  return "function "
    + alias4(((helper = (helper = helpers.name || (depth0 != null ? depth0.name : depth0)) != null ? helper : alias2),(typeof helper === alias3 ? helper.call(alias1,{"name":"name","hash":{},"data":data}) : helper)))
    + "(request, response) {\n    // replace with your code here\n    res.status(200).end();\n}\n\nexport { "
    + alias4(((helper = (helper = helpers.name || (depth0 != null ? depth0.name : depth0)) != null ? helper : alias2),(typeof helper === alias3 ? helper.call(alias1,{"name":"name","hash":{},"data":data}) : helper)))
    + " };\n";
},"useData":true});

/***/ }),
/* 7 */
/***/ (function(module, exports, __webpack_require__) {

var Handlebars = __webpack_require__(0);
module.exports = (Handlebars['default'] || Handlebars).template({"compiler":[7,">= 4.0.0"],"main":function(container,depth0,helpers,partials,data) {
    var helper, alias1=depth0 != null ? depth0 : (container.nullContext || {}), alias2=helpers.helperMissing, alias3="function", alias4=container.escapeExpression;

  return "const path = require('path');\nconst GeneratePackageJsonPlugin = require('generate-package-json-webpack-plugin');\nconst nodeExternals = require('webpack-node-externals');\n\nconst defaultPackageValues = {\n    'name': "
    + alias4(((helper = (helper = helpers.name || (depth0 != null ? depth0.name : depth0)) != null ? helper : alias2),(typeof helper === alias3 ? helper.call(alias1,{"name":"name","hash":{},"data":data}) : helper)))
    + " :,\n    'version': '1.0.0',\n    'main': './index.js'\n}\n\nmodule.exports = {\n    target: 'node',\n    externals: [ nodeExternals() ],\n    entry: './src/index.js',\n    output: {\n        path: path.resolve(__dirname, '../dist'),\n        filename: 'index.js',\n        library: "
    + alias4(((helper = (helper = helpers.name || (depth0 != null ? depth0.name : depth0)) != null ? helper : alias2),(typeof helper === alias3 ? helper.call(alias1,{"name":"name","hash":{},"data":data}) : helper)))
    + ",\n        libraryTarget: 'commonjs2'\n    },\n    module: {\n        rules: [\n            {\n                test: /\\.js/,\n                exclude: /(node_modules)/,\n                use: {\n                    loader: 'babel-loader',\n                    options: {\n                        presets: [ 'env' ]\n                    }\n                }\n            }\n        ]\n    },\n    plugins: [\n        new GeneratePackageJsonPlugin(defaultPackageValues, path.resolve(__dirname, '..', 'package.json'))\n    ]\n};\n\n";
},"useData":true});

/***/ })
/******/ ]);

==> create-serverless-function-0.0.3.tgz: package/createServerlessFunction.js <==
#!/usr/bin/env node
/******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId]) {
/******/ 			return installedModules[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			i: moduleId,
/******/ 			l: false,
/******/ 			exports: {}
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.l = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// define getter function for harmony exports
/******/ 	__webpack_require__.d = function(exports, name, getter) {
/******/ 		if(!__webpack_require__.o(exports, name)) {
/******/ 			Object.defineProperty(exports, name, {
/******/ 				configurable: false,
/******/ 				enumerable: true,
/******/ 				get: getter
/******/ 			});
/******/ 		}
/******/ 	};
/******/
/******/ 	// getDefaultExport function for compatibility with non-harmony modules
/******/ 	__webpack_require__.n = function(module) {
/******/ 		var getter = module && module.__esModule ?
/******/ 			function getDefault() { return module['default']; } :
/******/ 			function getModuleExports() { return module; };
/******/ 		__webpack_require__.d(getter, 'a', getter);
/******/ 		return getter;
/******/ 	};
/******/
/******/ 	// Object.prototype.hasOwnProperty.call
/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(__webpack_require__.s = 1);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ (function(module, exports) {

module.exports = require("handlebars");

/***/ }),
/* 1 */
/***/ (function(module, exports, __webpack_require__) {

const chalk = __webpack_require__(2);

const path = __webpack_require__(3);
const fs = __webpack_require__(4);

const program = __webpack_require__(5);

program.version('0.1.0')
    .arguments('<name> <directory>')
    .parse(process.argv);

if (program.args.length != 2) program.help();

function generateIndexJs(functionName, targetDir) {
    console.log(chalk.yellow('Generating index.js'));

    fs.mkdirSync(path.resolve(targetDir, 'src'));

    const indexJsTemplate = __webpack_require__(6);
    const indexJsPath = path.resolve(targetDir, 'src', 'index.js');
    const indexJsBody = indexJsTemplate({ name: functionName });

    fs.writeFileSync(indexJsPath, indexJsBody);

    console.log(chalk.green('Generated index.js'));
}

function generatePackageJson(functionName, targetDir) {
    console.log(chalk.yellow('Generating package.json'));

    const packageJson = {
        "name": functionName,
        "version": "0.0.1",
        "main": 'index.js',
        "devDependencies": {
            "babel-core": "^6.25.0",
            "babel-jest": "^20.0.3",
            "babel-loader": "^7.1.1",
            "babel-preset-env": "^1.6.0",
            "generate-package-json-webpack-plugin": "^0.1.2",
            "jest": "^20.0.4",
            "regenerator-runtime": "^0.10.5",
            "webpack": "^3.3.0",
            "webpack-node-externals": "^1.6.0"
        },
        "scripts": {
            "test": "jest",
            "build": "webpack --config ./config/webpack.config.js"
        },
        "jest": {
            "testEnvironment": "node"
        }
    };

    const packageJsonPath = path.resolve(targetDir, 'package.json');
    const packageJsonBody = JSON.stringify(packageJson, null, '    ');
    
    fs.writeFileSync(packageJsonPath, packageJsonBody);

    console.log(chalk.green('Generated package.json'));
}

function generateWebpackConfig(functionName, targetDir) {
    console.log(chalk.yellow('Generating WebPack configuration'));

    fs.mkdirSync(path.resolve(targetDir, 'config'));

    const webpackConfigTemplate = __webpack_require__(7);
    const webpackConfigPath = path.resolve(targetDir, 'config', 'webpack.config.js');
    const webpackConfigBody = webpackConfigTemplate({ name: functionName });

    fs.writeFileSync(webpackConfigPath, webpackConfigBody);

    console.log(chalk.green('Generated webpack configuration'));
}

generateIndexJs(...program.args);
generatePackageJson(...program.args);
generateWebpackConfig(...program.args);




/***/ }),
/* 2 */
/***/ (function(module, exports) {

module.exports = require("chalk");

/***/ }),
/* 3 */
/***/ (function(module, exports) {

module.exports = require("path");

/***/ }),
/* 4 */
/***/ (function(module, exports) {

module.exports = require("fs");

/***/ }),
/* 5 */
/***/ (function(module, exports) {

module.exports = require("commander");

/***/ }),
/* 6 */
/***/ (function(module, exports, __webpack_require__) {

var Handlebars = __webpack_require__(0);
module.exports = (Handlebars['default'] || Handlebars).template({"compiler":[7,">= 4.0.0"],"main":function(container,depth0,helpers,partials,data) {
    var helper, alias1=depth0 != null ? depth0 : (container.nullContext || {}), alias2=helpers.helperMissing, alias3="function", alias4=container.escapeExpression;

  return "function "
    + alias4(((helper = (helper = helpers.name || (depth0 != null ? depth0.name : depth0)) != null ? helper : alias2),(typeof helper === alias3 ? helper.call(alias1,{"name":"name","hash":{},"data":data}) : helper)))
    + "(request, response) {\n    // replace with your code here\n    response.status(200).end();\n}\n\nexport { "
    + alias4(((helper = (helper = helpers.name || (depth0 != null ? depth0.name : depth0)) != null ? helper : alias2),(typeof helper === alias3 ? helper.call(alias1,{"name":"name","hash":{},"data":data}) : helper)))
    + " };\n";
},"useData":true});

/***/ }),
/* 7 */
/***/ (function(module, exports, __webpack_require__) {

var Handlebars = __webpack_require__(0);
module.exports = (Handlebars['default'] || Handlebars).template({"compiler":[7,">= 4.0.0"],"main":function(container,depth0,helpers,partials,data) {
    var helper, alias1=depth0 != null ? depth0 : (container.nullContext || {}), alias2=helpers.helperMissing, alias3="function", alias4=container.escapeExpression;

  return "const path = require('path');\nconst GeneratePackageJsonPlugin = require('generate-package-json-webpack-plugin');\nconst nodeExternals = require('webpack-node-externals');\n\nconst defaultPackageValues = {\n    'name': ' "
    + alias4(((helper = (helper = helpers.name || (depth0 != null ? depth0.name : depth0)) != null ? helper : alias2),(typeof helper === alias3 ? helper.call(alias1,{"name":"name","hash":{},"data":data}) : helper)))
    + " ',\n    'version': '1.0.0',\n    'main': './index.js'\n}\n\nmodule.exports = {\n    target: 'node',\n    externals: [ nodeExternals() ],\n    entry: './src/index.js',\n    output: {\n        path: path.resolve(__dirname, '../dist'),\n        filename: 'index.js',\n        library: ' "
    + alias4(((helper = (helper = helpers.name || (depth0 != null ? depth0.name : depth0)) != null ? helper : alias2),(typeof helper === alias3 ? helper.call(alias1,{"name":"name","hash":{},"data":data}) : helper)))
    + " ',\n        libraryTarget: 'commonjs2'\n    },\n    module: {\n        rules: [\n            {\n                test: /\\.js/,\n                exclude: /(node_modules)/,\n                use: {\n                    loader: 'babel-loader',\n                    options: {\n                        presets: [ 'env' ]\n                    }\n                }\n            }\n        ]\n    },\n    plugins: [\n        new GeneratePackageJsonPlugin(defaultPackageValues, path.resolve(__dirname, '..', 'package.json'))\n    ]\n};\n\n";
},"useData":true});

/***/ })
/******/ ]);
